@@ -1,7 +1,6 @@
 # Boltlight - a LN node wrapper
 #
-# Copyright (C) 2021 boltlight contributors
-# Copyright (C) 2018 inbitcoin s.r.l.
+# Copyright (C) 2021-2022 boltlight contributors
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published
@@ -19,4 +18,6 @@
 # For a full list of contributors, please see the AUTHORS.md file.
 """Boltlight package."""
 
-__version__ = "2.0.0"
+import importlib.metadata
+
+__version__ = importlib.metadata.version('boltlight')
