@@ -154,7 +154,7 @@ class Err():  # pylint: disable=too-few-public-methods
         """Dispatch the called error dynamically."""
         def error_dispatcher(context, *params):
             """Abort gRPC call raising a grpc.RpcError to the API caller."""
-            if name in list(ERRORS.keys()):
+            if name in ERRORS:
                 scode = getattr(StatusCode, ERRORS[name]['code'])
                 msg = ''
                 if 'msg' in ERRORS[name]:
