@@ -1,6 +1,6 @@
 # Boltlight - a LN node wrapper
 #
-# Copyright (C) 2021 boltlight contributors
+# Copyright (C) 2021-2022 boltlight contributors
 # Copyright (C) 2018 inbitcoin s.r.l.
 #
 # This program is free software: you can redistribute it and/or modify
@@ -20,20 +20,22 @@
 """Implementation of boltlight.proto defined methods for electrum."""
 
 from ast import literal_eval
-from json import dumps
-from concurrent.futures import TimeoutError as TimeoutFutError, \
-    ThreadPoolExecutor
+from concurrent.futures import ThreadPoolExecutor
+from concurrent.futures import TimeoutError as TimeoutFutError
 from contextlib import ExitStack, suppress
+from json import dumps
 from logging import getLogger
 
-from . import boltlight_pb2 as pb, settings as sett
+from . import boltlight_pb2 as pb
+from . import settings as sett
 from .errors import Err
-from .utils.bitcoin import convert, Enforcer as Enf, get_address_type, \
-    get_channel_balances, has_amount_encoded
+from .utils.bitcoin import Enforcer as Enf
+from .utils.bitcoin import (
+    convert, get_address_type, get_channel_balances, has_amount_encoded)
 from .utils.db import session_scope
 from .utils.misc import handle_thread, set_defaults
-from .utils.network import check_req_params, get_thread_timeout, \
-    FakeContext, JSONRPCSession
+from .utils.network import (
+    FakeContext, JSONRPCSession, check_req_params, get_thread_timeout)
 from .utils.security import get_secret, unlock_node_with_password
 
 LOGGER = getLogger(__name__)
